Analytics - NOAA JetStream

# NOAA JetStream

Cloud Data Management System

# 📊 Analytics Dashboard

### Success Rate

-

### Avg Speed

-

### Total Transferred

-

### Completed Jobs

-

## Upload Trends (Last 30 Days)

## Job Status Distribution

## Top Source Paths

## Job Type Breakdown

## Analyze GCS Bucket

Analyze Google Cloud Storage buckets to get folder statistics, file counts, and size information.

Bucket Name Quick fill: PIFSC | AFSC | SWFSC | NEFSC | NWFSC
Folder Prefix (optional) Leave empty to analyze entire bucket

## Analysis Results